@@ -41,8 +41,12 @@ knit_print.huxtable <- function (x, options, ...) {
             latex = {
               latex_deps <- report_latex_dependencies(quiet = TRUE)
               tenv <- tabular_environment(x)
-              if (tenv %in% c("tabulary", "longtable")) latex_deps <- c(latex_deps,
-                list(rmarkdown::latex_dependency(tenv)))
+              if (tenv %in% c("tabulary", "longtable")) {
+                latex_deps <- c(latex_deps, list(rmarkdown::latex_dependency(tenv)))
+              }
+              if (getOption("huxtable.latex_use_fontspec", FALSE)) {
+                latex_deps <- c(latex_deps, list(rmarkdown::latex_dependency("fontspec")))
+              }
               knitr::asis_output(res, meta = latex_deps)
             },
             html = knitr::asis_output(htmlPreserve(res)),
